=========
uhammer
=========

Convenience layer on top of emcee package.


Credits
-------

This package was created with Cookiecutter_ and the `uweschmitt/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`uweschmitt/cookiecutter-pypackage`: https://github.com/uweschmitt/cookiecutter-pypackage
